==> nudge_leaderboard_ui-0.0.1.tar.gz: lib/features/leaderboard/presentation/pages/testingpage.dart <==
import 'package:nudge_core/nudge_core.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/pages/leaderboard_page.dart';
import 'package:flutter/material.dart';

class InputPage extends StatelessWidget {
  final TextEditingController _textController = TextEditingController();
  final TextEditingController _nameController = TextEditingController();
  final TextEditingController _emailController = TextEditingController();
  final TextEditingController _externalidController = TextEditingController();

  InputPage({super.key});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Input Page'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            TextField(
              controller: _textController,
              decoration: const InputDecoration(labelText: 'Enter rewardID'),
            ),
            const SizedBox(height: 16),
            TextField(
              controller: _nameController,
              decoration: const InputDecoration(labelText: 'Enter name'),
            ),
            const SizedBox(height: 16),
            TextField(
              controller: _emailController,
              decoration: const InputDecoration(labelText: 'Enter Email'),
            ),
            const SizedBox(height: 16),
            TextField(
              controller: _externalidController,
              decoration: const InputDecoration(labelText: 'Enter ExternalID'),
            ),
            const SizedBox(height: 16),
            ElevatedButton(
              onPressed: () {
                Nudge nudge = Nudge(apiKey: "");

                nudge.initSession(externalId: "1234");

                Navigator.of(context).push(
                  MaterialPageRoute(
                    builder: (context) => const LeaderboardScreen(
                      token: '',
                      rewardID: '64dca4979dac257b98e750a5',
                      externalID: 'Eudora39',
                    ),
                  ),
                );
              },
              child: const Text('Send to Leaderboard Page'),
            ),
          ],
        ),
      ),
    );
  }
}

==> nudge_leaderboard_ui-0.0.3.tar.gz: lib/features/leaderboard/presentation/pages/testingpage.dart <==
import 'package:nudge_core/nudge_core.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/pages/leaderboard_page.dart';
import 'package:flutter/material.dart';

class InputPage extends StatelessWidget {
  final TextEditingController _textController = TextEditingController();
  final TextEditingController _nameController = TextEditingController();
  final TextEditingController _emailController = TextEditingController();
  final TextEditingController _externalidController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Input Page'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            TextField(
              controller: _textController,
              decoration: InputDecoration(labelText: 'Enter rewardID'),
            ),
            SizedBox(height: 16),
            TextField(
              controller: _nameController,
              decoration: InputDecoration(labelText: 'Enter name'),
            ),
            SizedBox(height: 16),
            TextField(
              controller: _emailController,
              decoration: InputDecoration(labelText: 'Enter Email'),
            ),
            SizedBox(height: 16),
            TextField(
              controller: _externalidController,
              decoration: InputDecoration(labelText: 'Enter ExternalID'),
            ),
            const SizedBox(height: 16),
            ElevatedButton(
              onPressed: () {
                Nudge nudge = new Nudge(apiKey: "");

                nudge.initSession(externalId: "1234");

                Navigator.of(context).push(
                  MaterialPageRoute(
                    builder: (context) => LeaderboardScreen(
                      token: '',
                      rewardID: '64dca4979dac257b98e750a5',
                      externalID: 'Eudora39',
                    ),
                  ),
                );
              },
              child: Text('Send to Leaderboard Page'),
            ),
          ],
        ),
      ),
    );
  }
}
